@@ -15,7 +15,7 @@
  *
  * You should have received a copy of the GNU Lesser General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301
  * USA
  */
 
@@ -76,7 +76,7 @@ gsf_timestamp_as_string	(GsfTimestamp const *stamp)
 
 	/* Use an honest time_t for ctime.  */
 	t = stamp->timet;
-#warning ctime is not thread safe, use ctime_r if available
+/* FIXME FIXME FIXME  ctime is not thread safe, use ctime_r if available */
 	return g_strdup (ctime (&t));
 }
 
